<?php

namespace Drupal\synimport\Drush;

use Drush\Commands\DrushCommands;
use Drupal\synimport\Service\ImportInterface;
use Drupal\synimport\Classes\EmptyDirException;
use Drupal\synimport\Classes\Logger;

/**
 * A Drush commandfile.
 */
class DrushContentImport extends DrushCommands {

  /**
   * Service for service.
   *
   * @var Drupal\synimport\Service\Import
   */
  protected $synimport;

  /**
   * Command constructor.
   */
  public function __construct(ImportInterface $synimport) {
    $this->synimport = $synimport;
    $this->logger = new Logger();
  }

  /**
   * Synapse Content import.
   *
   * @param string $directory
   *   Content directory.
   *
   * @command synimport
   *   Full import from $directory.
   */
  public function import($directory) {
    $this->dirIsEmpty($directory);
    $this->synimport->import($directory);
  }

  /**
   * Synapse Contacts import.
   *
   * @param string $directory
   *   Content directory.
   *
   * @command synimport:contacts
   *   Contacts import from $directory.
   */
  public function importContacts($directory) {
    $this->dirIsEmpty($directory);
    $this->synimport->importContacts($directory);
  }

  /**
   * Synapse Taxonomy import.
   *
   * @param string $directory
   *   Content directory.
   *
   * @command synimport:taxonomy
   *   Taxonomy import from $directory.
   */
  public function importTaxonomy($directory) {
    $this->dirIsEmpty($directory);
    $this->synimport->importTaxonomy($directory);
  }

  /**
   * Synapse Nodes import.
   *
   * @param string $directory
   *   Content directory.
   *
   * @command synimport:node
   *   Nodes import from $directory.
   */
  public function importNode($directory) {
    $this->dirIsEmpty($directory);
    $this->synimport->importNode($directory);
  }

  /**
   * Synapse Menu import.
   *
   * @param string $directory
   *   Content directory.
   *
   * @command synimport:menu
   *   Menu import from $directory.
   */
  public function importMenu($directory) {
    $this->dirIsEmpty($directory);
    $this->synimport->importMenu($directory);
  }

  /**
   * Synapse Products import.
   *
   * @param string $directory
   *   Content directory.
   *
   * @command synimport:product
   *   Products import from $directory.
   */
  public function importProducts($directory) {
    $this->dirIsEmpty($directory);
    $this->synimport->importProducts($directory);
  }

  /**
   * Synapse Blocks import.
   *
   * @param string $directory
   *   Content directory.
   *
   * @command synimport:block
   *   Blocks import from $directory.
   */
  public function importBlocks($directory) {
    $this->dirIsEmpty($directory);
    $this->synimport->importBlocks($directory);
  }

  /**
   * Synapse Synlanding Config import.
   *
   * @param string $directory
   *   Content directory.
   *
   * @command synimport:synlanding_config
   *   Synlanding Config import from $directory.
   */
  public function setSynlandingFormBg($directory) {
    $this->dirIsEmpty($directory);
    $this->synimport->setSynlandingFormBg($directory);
  }

  /**
   * Check for empty directory.
   *
   * @throws Drupal\synimport\Classes\EmptyDirException
   *
   *   No file input.
   */
  private function dirIsEmpty($dirname) {
    if (!file_exists($dirname)) {
      $this->logger->error("Not a valid path");
      throw new EmptyDirException('Not a valid path');
    }
    if (!is_dir($dirname)) {
      $this->logger->error("Not a directory");
      throw new EmptyDirException('Not a directory');
    }
    foreach (scandir($dirname) as $file) {
      if (!in_array($file, ['.', '..', '.svn', '.git'])) {
        return FALSE;
      }
    }
    $this->logger->error("Dir is empty");
    throw new EmptyDirException('Dir is empty');
  }

}
